from flask import Flask

from fittrackee import db
from fittrackee.application.utils import (
    init_config,
    update_app_config_from_database,
)
from fittrackee.users.models import User


def init_database(app: Flask) -> None:
    """Init the database."""
    admin = User(
        username='admin', email='admin@example.com', password='mpwoadmin'
    )
    admin.admin = True
    admin.timezone = 'Europe/Paris'
    db.session.add(admin)
    db.session.commit()
    _, db_app_config = init_config()
    update_app_config_from_database(app, db_app_config)

    print('Initial data stored in database.')



from functools import wraps
from typing import Any, Callable, Union

from flask import request

from fittrackee.responses import HttpResponse

from .utils import verify_user


def authenticate(f: Callable) -> Callable:
    @wraps(f)
    def decorated_function(
        *args: Any, **kwargs: Any
    ) -> Union[Callable, HttpResponse]:
        verify_admin = False
        response_object, resp = verify_user(request, verify_admin)
        if response_object:
            return response_object
        return f(resp, *args, **kwargs)

    return decorated_function


def authenticate_as_admin(f: Callable) -> Callable:
    @wraps(f)
    def decorated_function(
        *args: Any, **kwargs: Any
    ) -> Union[Callable, HttpResponse]:
        verify_admin = True
        response_object, resp = verify_user(request, verify_admin)
        if response_object:
            return response_object
        return f(resp, *args, **kwargs)

    return decorated_function
